@@ -1,11 +1,12 @@
-## Copyright (C) 1996, 1997 John W. Eaton
+## Copyright (C) 1994, 1996, 1997, 1999, 2000, 2005, 2006, 2007, 2008, 2009
+##               John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,13 +14,13 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Mapping Function} {} acsc (@var{x})
-## Compute the inverse cosecant of each element of @var{x}.
+## Compute the inverse cosecant in radians for each element of @var{x}.
+## @seealso{csc, acscd}
 ## @end deftypefn
 
 ## Author: jwe
@@ -33,3 +34,15 @@ function w = acsc (z)
   w = asin (1 ./ z);
 
 endfunction
+
+%!test
+%! rt2 = sqrt (2);
+%! rt3 = sqrt (3);
+%! v = [pi/6, pi/4, pi/3, pi/2, pi/3, pi/4, pi/6];
+%! x = [2, rt2, 2*rt3/3, 1, 2*rt3/3, rt2, 2];
+%! assert(all (abs (acsc (x) - v) < sqrt (eps)));
+
+%!error acsc ();
+
+%!error acsc (1, 2);
+
