@@ -1,4 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2005, 2006, 2007
+## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2005, 2006, 2007, 2009
 ##               Kurt Hornik
 ##
 ## This file is part of Octave.
@@ -19,7 +19,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} stdnormal_inv (@var{x})
-## For each component of @var{x}, compute compute the quantile (the
+## For each component of @var{x}, compute the quantile (the
 ## inverse of the CDF) at @var{x} of the standard normal distribution.
 ## @end deftypefn
 
