@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 2003, 2004, 2005, 2006, 2007 John W. Eaton
+Copyright (C) 1996, 1997, 2003, 2004, 2005, 2006, 2007, 2008 John W. Eaton
 
 This file is part of Octave.
 
@@ -51,21 +51,19 @@ along with Octave; see the file COPYING.  If not, see
 #include "error.h"
 #include "gripes.h"
 #include "load-save.h"
+#include "ls-ascii-helper.h"
+#include "ls-oct-ascii.h"
 #include "oct-obj.h"
 #include "oct-map.h"
 #include "ov-cell.h"
 #include "pager.h"
 #include "pt-exp.h"
-#include "symtab.h"
-#include "sysdep.h"
 #include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
 #include "version.h"
 #include "dMatrix.h"
 
-#include "ls-oct-ascii.h"
-
 // The number of decimal digits to use when writing ascii data.
 static int Vsave_precision = 16;
 
@@ -83,6 +81,10 @@ extract_keyword (std::istream& is, const char *keyword, const bool next_only)
 {
   std::string retval;
 
+  int ch = is.peek ();
+  if (next_only && ch != '%' && ch != '#')
+    return retval;
+
   char c;
   while (is.get (c))
     {
@@ -108,23 +110,14 @@ extract_keyword (std::istream& is, const char *keyword, const bool next_only)
 	      while (is.get (c) && (c == ' ' || c == '\t' || c == ':'))
 		; // Skip whitespace and the colon.
 
-	      if (c != '\n' && c != '\r')
-		{
-		  value << c;
-		  while (is.get (c) && c != '\n' && c != '\r')
-		    value << c;
-		}
-
-	      retval = value.str ();
+	      is.putback(c);
+	      retval = read_until_newline (is, false);
 	      break;
 	    }
 	  else if (next_only)
 	    break;
 	  else
-	    {
-	      while (is.get (c) && c != '\n' && c != '\r')
-		; // Skip to end of line.
-	    }
+	    skip_until_newline (is, false);
 	}
     }
 
@@ -257,11 +250,8 @@ read_ascii_data (std::istream& is, const std::string& filename, bool& global,
       return std::string ();
     }
 
-  if (name == CELL_ELT_TAG)
-    {
-      // This is OK -- name won't be used.
-    }
-  else if (! valid_identifier (name))
+  if (! (name == ".nargin." || name == ".nargout."
+	 || name == CELL_ELT_TAG || valid_identifier (name)))
     {
       error ("load: bogus identifier `%s' found in file `%s'",
 	     name.c_str (), filename.c_str ());
@@ -277,7 +267,7 @@ read_ascii_data (std::istream& is, const std::string& filename, bool& global,
       std::string typ;
       size_t pos = tag.rfind (' ');
 
-      if (pos != NPOS)
+      if (pos != std::string::npos)
 	{
 	  global = SUBSTRING_COMPARE_EQ (tag, 0, 6, "global");
 
