@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006, 2007, 2008 John W. Eaton
+Copyright (C) 2006, 2007, 2008, 2009 John W. Eaton
 
 This file is part of Octave.
 
@@ -33,6 +33,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "f77-fcn.h"
 #include "lo-ieee.h"
+#include "oct-locbuf.h"
 
 // mxArray must be declared as a class before including mexproto.h.
 class mxArray;
@@ -497,11 +498,10 @@ public:
 
   void *get_data (void) const
   {
-    void *retval = 0;
+    void *retval = val.mex_get_data ();
 
-    if (is_char ()
-	|| (is_numeric () && is_real_type () && ! is_range ()))
-      retval = maybe_mark_foreign (val.mex_get_data ());
+    if (retval)
+      maybe_mark_foreign (retval);
     else
       request_mutation ();
 
@@ -3021,11 +3021,13 @@ typedef F77_RET_T (*fmex_fptr) (int& nlhs, mxArray **plhs, int& nrhs, mxArray **
 
 octave_value_list
 call_mex (bool have_fmex, void *f, const octave_value_list& args,
-	  int nargout, octave_mex_function *curr_mex_fcn)
+	  int nargout_arg, octave_mex_function *curr_mex_fcn)
 {
   // Use at least 1 for nargout since even for zero specified args,
   // still want to be able to return an ans.
 
+  volatile int nargout = nargout_arg;
+
   int nargin = args.length ();
   OCTAVE_LOCAL_BUFFER (mxArray *, argin, nargin);
   for (int i = 0; i < nargin; i++)
@@ -3260,31 +3262,42 @@ mexGetVariable (const char *space, const char *name)
 {
   mxArray *retval = 0;
 
-  // FIXME -- this should be in variable.cc, but the correct
-  // functionality is not exported.  Particularly, get_global_value()
-  // generates an error if the symbol is undefined.
-
-  symbol_record *sr = 0;
+  octave_value val;
 
   if (! strcmp (space, "global"))
-    sr = global_sym_tab->lookup (name);
-  else if (! strcmp (space, "caller"))
-    sr = curr_sym_tab->lookup (name);
-  else if (! strcmp (space, "base"))
-    sr = top_level_sym_tab->lookup (name);
+    val = get_global_value (name);
   else
-    mexErrMsgTxt ("mexGetVariable: symbol table does not exist");
-
-  if (sr)
     {
-      octave_value sr_def = sr->def ();
+      // FIXME -- should this be in variables.cc?
 
-      if (sr_def.is_defined ())
+      unwind_protect::begin_frame ("mexGetVariable");
+
+      bool caller = ! strcmp (space, "caller");
+      bool base = ! strcmp (space, "base");
+
+      if (caller || base)
 	{
-	  retval = mex_context->make_value (sr_def);
+	  if (caller)
+	    octave_call_stack::goto_caller_frame ();
+	  else
+	    octave_call_stack::goto_base_frame ();
 
-	  retval->set_name (name);
+	  if (! error_state)
+	    unwind_protect::add (octave_call_stack::unwind_pop);
+
+	  val = symbol_table::varval (name);
 	}
+      else
+	mexErrMsgTxt ("mexGetVariable: symbol table does not exist");
+
+      unwind_protect::run_frame ("mexGetVariable");
+    }
+
+  if (val.is_defined ())
+    {
+      retval = mex_context->make_value (val);
+
+      retval->set_name (name);
     }
 
   return retval;
@@ -3315,21 +3328,29 @@ mexPutVariable (const char *space, const char *name, mxArray *ptr)
     set_global_value (name, mxArray::as_octave_value (ptr));
   else
     {
-      // FIXME -- this belongs in variables.cc.
+      // FIXME -- should this be in variables.cc?
 
-      symbol_record *sr = 0;
+      unwind_protect::begin_frame ("mexPutVariable");
 
-      if (! strcmp (space, "caller"))
-	sr = curr_sym_tab->lookup (name, true);
-      else if (! strcmp (space, "base"))
-	sr = top_level_sym_tab->lookup (name, true);
+      bool caller = ! strcmp (space, "caller");
+      bool base = ! strcmp (space, "base");
+
+      if (caller || base)
+	{
+	  if (caller)
+	    octave_call_stack::goto_caller_frame ();
+	  else
+	    octave_call_stack::goto_base_frame ();
+
+	  if (! error_state)
+	    unwind_protect::add (octave_call_stack::unwind_pop);
+
+	  symbol_table::varref (name) = mxArray::as_octave_value (ptr);
+	}
       else
 	mexErrMsgTxt ("mexPutVariable: symbol table does not exist");
 
-      if (sr)
-	sr->define (mxArray::as_octave_value (ptr));
-      else
-	panic_impossible ();
+      unwind_protect::run_frame ("mexPutVariable");
     }
 
   return 0;
@@ -3408,7 +3429,7 @@ mexLock (void)
       else
 	mex_lock_count[fname]++;
 
-      mlock (fname);
+      mlock ();
     }
 }
 
